import {
  PageContainer,
  ProForm,
  ProFormSelect,
  ProFormText,
} from "@ant-design/pro-components";
import { queryDict } from "@/utils/request";
import { useNavigate, useSearchParams } from "react-router-dom";
import { Card, Col, Row, Space } from "antd";
import { useEffect, useRef } from "react";
import {
  savetCooperationPerson,
  gettCooperationPersonDetail,
  updatetCooperationPerson,
  getCooperationUnitsList,
} from "@/services/cooperationUnits";

export default (props) => {
  const [searchParams] = useSearchParams();
  const id = searchParams.get("id");
  const orgId = searchParams.get("orgId");
  const navigate = useNavigate();

  const formRef = useRef();
  useEffect(() => {
    if (id) {
      gettCooperationPersonDetail(id).then((res) => {
        formRef.current.setFieldsValue({
          ...res,
        });
      });
    }
  }, [id]);

  const onFinish = async (values) => {
    console.log(values);
    if (id) {
      updatetCooperationPerson(id, {
        ...values,
      }).then((res) => {
        navigate(-1);
      });
    } else {
      savetCooperationPerson({
        ...values,
      }).then((res) => {
        navigate(-1);
      });
    }
  };

  return (
    <PageContainer>
      <Card>
        <ProForm
          formRef={formRef}
          layout={"horizontal"}
          labelCol={{ span: 8 }}
          wrapperCol={{ span: 12 }}
          onFinish={onFinish}
          initialValues={{ orgId:Number(orgId)||null }}
          submitter={{
            searchConfig: {
              resetText: "返回",
            },
            onReset: () => navigate(-1),
            render: (props, doms) => {
              return (
                <Row>
                  <Col span={8} offset={8}>
                    <Space>{doms}</Space>
                  </Col>
                </Row>
              );
            },
          }}
        >
          <ProFormText
            name="name"
            label="姓名"
            width={460}
            rules={[{ required: true, message: "请输入姓名" }]}
          />
          <ProFormSelect
            name="orgId"
            label="机构"
            request={() => queryDict(getCooperationUnitsList)()}
            rules={[{ required: true, message: "请选择机构" }]}
            width={460}
          />

          <ProFormText name="idNo" label="身份证号" width={460} />
          <ProFormSelect
            name="sex"
            label="性别"
            width={460}
            options={[
              {
                value: 1,
                label: "男",
              },
              {
                value: 2,
                label: "女",
              },
              {
                value: 9,
                label: "未知",
              },
            ]}
          />

          <ProFormText name="ethnic" label="名族" width={460} />
          <ProFormText name="politicalStatus" label="政治面貌" width={460} />
          <ProFormText name="phone" label="联系电话" width={460} />
          <ProFormSelect
            name="isHealthCertificate"
            label="是否有健康证"
            width={460}
            options={[
              {
                value: 0,
                label: "--请选择--",
              },
              {
                value: 1,
                label: "是",
              },
              {
                value: 2,
                label: "否",
              },
            ]}
          />
          <ProFormText name="homeAddr" label="家庭住址" width={460} />
        </ProForm>
      </Card>
    </PageContainer>
  );
};
