import {
  savePurchase,
  updatePurchase,
  getPurchaseDetail,
} from "@/services/purchase";
import { getStoreList } from "@/services/stock";
import {
  PageContainer,
  ProForm,
  ProFormSelect,
  ProFormText,
  ProFormDigit,
  ProFormDatePicker ,
} from "@ant-design/pro-components";
import { useNavigate, useSearchParams } from "react-router-dom";
import { Card, Col, message, Row, Space, Form, Button } from "antd";
import { useEffect, useRef, useState } from "react";
import { MinusCircleOutlined, PlusOutlined } from "@ant-design/icons";
import { floatMultiply, floatDivide } from "@/utils/float";

export default (props) => {
  const [searchParams] = useSearchParams();
  const id = searchParams.get("id");
  const [storeList, setStoreList] = useState([]);
  const [isCompleted, setIsCompleted] = useState(false);

  const navigate = useNavigate();

  const formRef = useRef();
  useEffect(() => {
    getStoreList({ pageSize: 9999 }).then((res) => {
      setStoreList(
        res?.records?.map((x) => ({
          label: x.name,
          value: x.id,
        }))
      );
    });
  }, []);

  useEffect(() => {
    if (id) {
      getPurchaseDetail(id).then((res) => {
        setIsCompleted(res.isCompleted);
        formRef.current.setFieldsValue({
          ...res,
          itemsList: res.itemsList?.map((x) => ({
            ...x,
            planUnitPrice: x.planUnitPrice
              ? floatDivide(x.planUnitPrice, 100)
              : null,
          })),
        });
      });
    }
  }, [id]);

  const onFinish = async (values) => {
    let data = {
      id: id ? Number(id) : null,
      ...values,
      itemsList: values.itemsList?.map((x) => ({
        ...x,
        planUnitPrice: floatMultiply(x.planUnitPrice, 100),
      })),
    };

    savePurchase(data).then((res) => {
      // message.success("添加成功");
      navigate(-1);
    });

    return false;
  };

  return (
    <PageContainer>
      <Card>
        <ProForm
          formRef={formRef}
          layout={"horizontal"}
          labelCol={{ span: 2 }}
          wrapperCol={{ span: 8 }}
          onFinish={onFinish}
          initialValues={{ type: "1", state: "1" }}
          submitter={{
            searchConfig: {
              resetText: "返回",
            },
            submitButtonProps: {
              disabled: isCompleted,
            },
            onReset: () => navigate(-1),
            render: (props, doms) => {
              console.log(props, doms, "propsprops");
              console.log(props?.form?.getFieldsValue(), "propsprops");
              return (
                <Row>
                  <Col span={8} offset={2}>
                    <Space>{doms}</Space>
                  </Col>
                </Row>
              );
            },
          }}
        >
          <ProFormText
            name="title"
            label="采购计划"
            allowClear={false}
            placeholder="请输入采购计划"
            rules={[{ required: true, message: "请输入采购计划" }]}
            width={480}
          />

          <ProFormDatePicker 
            name="planDate"
            allowClear={false}
            label="计划时间"
            placeholder="请输入计划时间"
            rules={[{ required: true, message: "请输入计划时间" }]}
            width={480}
          />

          <Form.Item
            label="采购清单"
            labelCol={{ span: 2 }}
            wrapperCol={{ span: 22 }}
          >
            <Form.List name="itemsList">
              {(fields, { add, remove }) => (
                <>
                  {fields.map(({ key, name, ...restField }) => (
                    <Space
                      key={key}
                      style={{ display: "flex" }}
                      align="baseline"
                    >
                      <ProFormSelect
                        {...restField}
                        name={[name, "storeId"]}
                        allowClear={false}
                        label="库存名称"
                        placeholder="请选择库存名称"
                        rules={[{ required: true, message: "请输入选择名称" }]}
                        options={storeList}
                      />

                      <ProFormDigit
                        {...restField}
                        allowClear={false}
                        name={[name, "planAmount"]}
                        label="计划数量"
                        placeholder="请输入计划数量"
                        rules={[{ required: true, message: "请输入计划数量" }]}
                        // width={150}
                        fieldProps={{
                          precision: 10,
                          formatter: (value) => value,
                        }}
                      />
                      <ProFormDigit
                        {...restField}
                        name={[name, "planUnitPrice"]}
                        label="预估单价"
                        placeholder="请输入预估单价"
                        rules={[{ required: true, message: "请输入预估单价" }]}
                        fieldProps={{ precision: 2, prefix: "￥" }}
                        // width={150}
                      />
                      {!isCompleted && (
                        <MinusCircleOutlined onClick={() => remove(name)} />
                      )}
                    </Space>
                  ))}
                  {!isCompleted && (
                    <Form.Item>
                      <Button
                        type="dashed"
                        onClick={() => add()}
                        icon={<PlusOutlined />}
                      >
                        添加
                      </Button>
                    </Form.Item>
                  )}
                </>
              )}
            </Form.List>
          </Form.Item>
        </ProForm>
      </Card>
    </PageContainer>
  );
};
