import React from 'react';
import { Row, Col, Radio, DatePicker } from 'antd';
import moment from 'moment';

const { RangePicker } = DatePicker;
const radioDateOptions = [
  { label: '本月', value: '1' },
  // { label: '本季', value: '2' },
  { label: '本年', value: '3' },
];
const radioUnitOptions = [
  { label: '按天', value: '1' },
  { label: '按月', value: '2' },
];

export const lastDays = [
  moment().subtract(15, 'days'),
  moment(),
];

export const yearRange = [
  moment().startOf('year'),
  moment(),
]
export const quarterRange = [
  moment().startOf('quarter'),
  moment(),
]
export const monthRange = [
  moment().startOf('quarter'),
  moment(),
]

export default (props) => {
  const [dateRange, setDateRange] = React.useState(lastDays);
  const [radioValue, setRadioValue] = React.useState();
  const [unitValue, setUnitValue] = React.useState('1');

  const onPickerChange = val => {
    setDateRange(val);
    setRadioValue();
  }

  const onRadioChange = e => {
    const val = e.target.value;
    setRadioValue(val);
    let dateRange = [];
    switch (val) {
      case '1':
        dateRange = monthRange;
        break;
      case '2':
        dateRange = quarterRange;
        break;
      case '3':
        dateRange = yearRange;
        setUnitValue('2');
        break;
      default:
        break;
    }
    
    setDateRange(dateRange);
  }

  const onUnitChange = e => {
    const val = e.target.value;
    setUnitValue(val);
  }

  React.useEffect(() => {
    if (typeof props.onChange === 'function') {
      const dt = getStrValue(dateRange);
      props.onChange({
        startDate: dt[0],
        endDate: dt[1],
        unit: unitValue,
      });
    }
  }, [dateRange, unitValue, props.onChange]);

  return (
    <Row style={{ width: '560px' }} gutter={8}>
      <Col span={7}>
        {
          !props.hideUnit && (
            <Radio.Group
              options={radioUnitOptions}
              value={unitValue}
              onChange={onUnitChange}
            />
          )
        }
      </Col>
      <Col span={10}>
        <RangePicker value={dateRange} onChange={onPickerChange} />
      </Col>
      <Col span={7}>
        <Radio.Group
          options={radioDateOptions}
          value={radioValue}
          onChange={onRadioChange}
          optionType="button"
          buttonStyle="solid"
        />
      </Col>
    </Row>
  )
}

export function getStrValue(range) {
  return [
    range[0].format('YYYY-MM-DD'),
    range[1].format('YYYY-MM-DD'),
  ];
}
